@@ -13,7 +13,7 @@
 
     Also, we define types such as file address lengths.
 
-    Version $Id: bc_types.h 3676 2006-11-21 20:14:47Z kerns $
+    Version $Id: bc_types.h 5984 2007-11-25 16:12:14Z kerns $
 
  */
 /*
@@ -25,8 +25,8 @@
    many others, a complete list can be found in the file AUTHORS.
    This program is Free Software; you can redistribute it and/or
    modify it under the terms of version two of the GNU General Public
-   License as published by the Free Software Foundation plus additions
-   that are listed in the file LICENSE.
+   License as published by the Free Software Foundation and included
+   in the file LICENSE.
 
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -62,7 +62,7 @@ typedef unsigned int u_int;
 
 #ifndef HAVE_INTXX_T
 # if (SIZEOF_CHAR == 1)
-typedef char int8_t;
+typedef signed char int8_t;
 # else
 #  error "8 bit int type not found."
 # endif
