@@ -18,8 +18,8 @@
    many others, a complete list can be found in the file AUTHORS.
    This program is Free Software; you can redistribute it and/or
    modify it under the terms of version two of the GNU General Public
-   License as published by the Free Software Foundation plus additions
-   that are listed in the file LICENSE.
+   License as published by the Free Software Foundation and included
+   in the file LICENSE.
 
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -69,6 +69,9 @@ extern "C" char *tgetstr (const char*, char**);
 extern "C" char *tgoto (const char *, int, int);
 #elif HAVE_HPUX_OS
 #include <term.h>
+#elif HAVE_AIX_OS 
+#include <curses.h>
+#include <term.h>
 #elif defined (__digital__) && defined (__unix__)
 extern "C" int tgetent(void *, const char *);
 extern "C" int tgetnum(const char *);
@@ -82,7 +85,7 @@ extern "C" char *tgoto (const char *, int, int);
 
 
 /* From termios library */
-#ifdef HAVE_HPUX_OS
+#if defined(HAVE_HPUX_OS) || defined(HAVE_AIX_OS)
 static char *BC;
 static char *UP;
 #else
