@@ -31,7 +31,7 @@
  *
  *     Kern Sibbald, December MMI
  *
- *   Version $Id: ua_run.c 5774 2007-10-21 17:36:17Z ricozz $
+ *   Version $Id: ua_run.c 6390 2008-02-10 09:26:42Z ricozz $
  */
 
 #include "bacula.h"
@@ -122,6 +122,9 @@ try_again:
    jcr->verify_job = rc.verify_job;
    jcr->previous_job = rc.previous_job;
    jcr->pool = rc.pool;
+   if (jcr->pool != jcr->job->pool) {
+      pm_strcpy(jcr->pool_source, _("User input"));
+   }
    set_rwstorage(jcr, rc.store);
    jcr->client = rc.client;
    pm_strcpy(jcr->client_name, rc.client->name());
