@@ -1,21 +1,14 @@
-/*
- * Bacula GNOME User Agent specific configuration and defines
- *
- *     Kern Sibbald, March 2002
- *
- *     Version $Id: console_conf.h 3676 2006-11-21 20:14:47Z kerns $
- */
 /*
    Bacula® - The Network Backup Solution
 
-   Copyright (C) 2002-2006 Free Software Foundation Europe e.V.
+   Copyright (C) 2002-2008 Free Software Foundation Europe e.V.
 
    The main author of Bacula is Kern Sibbald, with contributions from
    many others, a complete list can be found in the file AUTHORS.
    This program is Free Software; you can redistribute it and/or
    modify it under the terms of version two of the GNU General Public
-   License as published by the Free Software Foundation plus additions
-   that are listed in the file LICENSE.
+   License as published by the Free Software Foundation and included
+   in the file LICENSE.
 
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -32,6 +25,13 @@
    (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
    Switzerland, email:ftf@fsfeurope.org.
 */
+/*
+ * Bacula GNOME User Agent specific configuration and defines
+ *
+ *     Kern Sibbald, March 2002
+ *
+ *     Version $Id: console_conf.h 7164 2008-06-18 19:22:03Z kerns $
+ */
 
 #ifndef __CONSOLE_CONF_H_
 #define __CONSOLE_CONF_H_
@@ -63,11 +63,11 @@ enum {
 /* Definition of the contents of each Resource */
 struct DIRRES {
    RES   hdr;
-   int   DIRport;                     /* UA server port */
+   uint32_t DIRport;                  /* UA server port */
    char *address;                     /* UA server address */
    char *password;                    /* UA server password */
-   int tls_enable;                    /* Enable TLS */
-   int tls_require;                   /* Require TLS */
+   bool tls_enable;                   /* Enable TLS */
+   bool tls_require;                  /* Require TLS */
    char *tls_ca_certfile;             /* TLS CA Certificate File */
    char *tls_ca_certdir;              /* TLS CA Certificate Directory */
    char *tls_certfile;                /* TLS Client Certificate File */
@@ -79,14 +79,13 @@ struct DIRRES {
 struct CONFONTRES {
    RES   hdr;
    char *fontface;                    /* Console Font specification */
-   int require_ssl;                   /* Require SSL on all connections */
 };
 
 struct CONRES {
    RES   hdr;
    char *password;                    /* UA server password */
-   int tls_enable;                    /* Enable TLS on all connections */
-   int tls_require;                   /* Require TLS on all connections */
+   bool tls_enable;                   /* Enable TLS on all connections */
+   bool tls_require;                  /* Require TLS on all connections */
    char *tls_ca_certfile;             /* TLS CA Certificate File */
    char *tls_ca_certdir;              /* TLS CA Certificate Directory */
    char *tls_certfile;                /* TLS Client Certificate File */
