@@ -1,7 +1,7 @@
 /*
    Bacula® - The Network Backup Solution
 
-   Copyright (C) 2007-2007 Free Software Foundation Europe e.V.
+   Copyright (C) 2007-2008 Free Software Foundation Europe e.V.
 
    The main author of Bacula is Kern Sibbald, with contributions from
    many others, a complete list can be found in the file AUTHORS.
@@ -20,14 +20,14 @@
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
    02110-1301, USA.
 
-   Bacula® is a registered trademark of John Walker.
+   Bacula® is a registered trademark of Kern Sibbald.
    The licensor of Bacula is the Free Software Foundation Europe
    (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
    Switzerland, email:ftf@fsfeurope.org.
 */
  
 /*
- *   Version $Id: prerestore.cpp 5713 2007-10-03 11:36:47Z kerns $
+ *   Version $Id: prerestore.cpp 7419 2008-07-23 08:23:02Z kerns $
  *
  *  preRestore -> dialog put up to determine the restore type
  *
@@ -59,7 +59,7 @@ prerestorePage::prerestorePage()
  */
 void prerestorePage::buildPage()
 {
-   m_name = "Restore";
+   m_name = tr("Restore");
    setupUi(this);
    pgInitialize();
    m_console->notify(false);
@@ -73,7 +73,7 @@ void prerestorePage::buildPage()
    jobCombo->addItems(m_console->job_list);
    filesetCombo->addItems(m_console->fileset_list);
    clientCombo->addItems(m_console->client_list);
-   poolCombo->addItem("Any");
+   poolCombo->addItem(tr("Any"));
    poolCombo->addItems(m_console->pool_list);
    storageCombo->addItems(m_console->storage_list);
    /* current or before . .  Start out with current checked */
@@ -85,7 +85,7 @@ void prerestorePage::buildPage()
    if (m_dataInType == R_NONE) {
       selectJobRadio->setChecked(true);
       selectJobIdsRadio->setChecked(false);
-      jobIdEdit->setText("Comma separted list of jobs id's");
+      jobIdEdit->setText(tr("Comma separted list of Job Ids"));
       jobIdEdit->setEnabled(false);
    } else if (m_dataInType == R_JOBIDLIST) {
       selectJobIdsRadio->setChecked(true);
@@ -101,7 +101,7 @@ void prerestorePage::buildPage()
    } else if (m_dataInType == R_JOBDATETIME) {
       selectJobRadio->setChecked(true);
       selectJobIdsRadio->setChecked(false);
-      jobIdEdit->setText("Comma separted list of jobs id's");
+      jobIdEdit->setText(tr("Comma separted list of Job Ids"));
       jobIdEdit->setEnabled(false);
       recentCheckBox->setCheckState(Qt::Unchecked);
       jobRadioClicked(true);
@@ -146,7 +146,7 @@ void prerestorePage::okButtonPushed()
    cmd += " fileset=\"" + filesetCombo->currentText() + "\"";
    cmd += " client=\"" + clientCombo->currentText() + "\"";
    if (selectJobRadio->isChecked()) {
-      if (poolCombo->currentText() != "Any" ){
+      if (poolCombo->currentText() != tr("Any") ){
          cmd += " pool=\"" + poolCombo->currentText() + "\"";
       }
       cmd += " storage=\"" + storageCombo->currentText() + "\"";
@@ -171,12 +171,10 @@ void prerestorePage::okButtonPushed()
       Pmsg1(000, "preRestore command \'%s\'\n", cmd.toUtf8().data());
    }
    m_console->write_dir(cmd.toUtf8().data());
-// consoleCommand(cmd);
 
    /* Note, do not turn notifier back on here ... */
    if (selectFilesRadio->isChecked()) {
       setConsoleCurrent();
-//    new restorePage();
       closeStackPage();
    } else {
       closeStackPage();
@@ -191,7 +189,7 @@ void prerestorePage::okButtonPushed()
  */
 void prerestorePage::cancelButtonPushed()
 {
-   mainWin->set_status("Canceled");
+   mainWin->set_status(tr("Canceled"));
    this->hide();
    m_console->notify(true);
    closeStackPage();
@@ -210,7 +208,7 @@ void prerestorePage::job_name_change(int index)
    if (m_console->get_job_defaults(job_defs)) {
       filesetCombo->setCurrentIndex(filesetCombo->findText(job_defs.fileset_name, Qt::MatchExactly));
       clientCombo->setCurrentIndex(clientCombo->findText(job_defs.client_name, Qt::MatchExactly));
-      poolCombo->setCurrentIndex(poolCombo->findText(job_defs.pool_name, Qt::MatchExactly));
+      poolCombo->setCurrentIndex(poolCombo->findText(tr("Any"), Qt::MatchExactly));
       storageCombo->setCurrentIndex(storageCombo->findText(job_defs.store_name, Qt::MatchExactly));
    }
 }
@@ -269,7 +267,7 @@ bool prerestorePage::checkJobIdList()
    /* Need to check and make sure the text is a comma separated list of integers */
    QString line = jobIdEdit->text();
    if (line.contains(" ")) {
-      QMessageBox::warning(this, tr("Bat"),
+      QMessageBox::warning(this, "Bat",
          tr("There can be no spaces in the text for the joblist.\n"
          "Press OK to continue?"), QMessageBox::Ok );
       return false;
@@ -301,8 +299,8 @@ bool prerestorePage::checkJobIdList()
       }
    }
    if (!allintokay){
-      QMessageBox::warning(this, tr("Bat"),
-         tr("The string is not a comma separated list if integers.\n"
+      QMessageBox::warning(this, "Bat",
+         tr("The string is not a comma separated list of integers.\n"
          "Press OK to continue?"), QMessageBox::Ok );
       return false;
    }
@@ -313,7 +311,7 @@ bool prerestorePage::checkJobIdList()
       return false;
    }
    if (!alljobok){
-      QMessageBox::warning(this, tr("Bat"),
+      QMessageBox::warning(this, "Bat",
          tr("All jobs in the list must be of the same jobName and same client.\n"
          "Press OK to continue?"), QMessageBox::Ok );
       return false;
