@@ -30,7 +30,7 @@
  *
  *     Kern Sibbald, May MMIII
  *
- *   Version $Id: status.c 7433 2008-07-25 06:16:09Z kerns $
+ *   Version $Id: status.c 7949 2008-10-30 12:06:26Z kerns $
  *
  */
 
@@ -378,7 +378,7 @@ static void list_running_jobs(void sendit(const char *msg, int len, void *sarg),
       }
       dcr = jcr->dcr;
       rdcr = jcr->read_dcr;
-      if ((dcr && dcr->device) || rdcr && rdcr->device) {
+      if ((dcr && dcr->device) || (rdcr && rdcr->device)) {
          bstrncpy(JobName, jcr->Job, sizeof(JobName));
          /* There are three periods after the Job name */
          char *p;
