@@ -1,22 +1,14 @@
-/*
- *
- *   Bacula Gnome Tray Monitor
- *
- *     Nicolas Boichat, August MMIV
- *
- *     Version $Id: tray-monitor.c 3718 2006-12-01 08:45:40Z robertnelson $
- */
 /*
    Bacula® - The Network Backup Solution
 
-   Copyright (C) 2004-2006 Free Software Foundation Europe e.V.
+   Copyright (C) 2004-2007 Free Software Foundation Europe e.V.
 
    The main author of Bacula is Kern Sibbald, with contributions from
    many others, a complete list can be found in the file AUTHORS.
    This program is Free Software; you can redistribute it and/or
    modify it under the terms of version two of the GNU General Public
-   License as published by the Free Software Foundation plus additions
-   that are listed in the file LICENSE.
+   License as published by the Free Software Foundation and included
+   in the file LICENSE.
 
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -33,12 +25,19 @@
    (FSFE), Fiduciary Program, Sumatrastrasse 25, 8006 Zürich,
    Switzerland, email:ftf@fsfeurope.org.
 */
+/*
+ *
+ *   Bacula Gnome Tray Monitor
+ *
+ *     Nicolas Boichat, August MMIV
+ *
+ *     Version $Id: tray-monitor.c 5752 2007-10-16 19:00:51Z kerns $
+ */
+
 
 #include "bacula.h"
 #include "tray-monitor.h"
 
-#include "eggstatusicon.h"
-
 #include "generic.xpm"
 
 #define TRAY_DEBUG_MEMORY 0
@@ -92,7 +91,7 @@ static void DaemonChanged(GtkWidget *widget, monitoritem* data);
 static gboolean delete_event(GtkWidget *widget, GdkEvent  *event, gpointer   data);
 
 static guint timerTag;
-static EggStatusIcon *mTrayIcon;
+static GtkStatusIcon *mTrayIcon;
 static GtkWidget *mTrayMenu;
 static GtkWidget *window;
 static GtkWidget *textview;
@@ -101,6 +100,8 @@ static GtkWidget *timeoutspinner;
 char** xpm_generic_var;
 static gboolean blinkstate = TRUE;
 
+PangoFontDescription *font_desc = NULL;
+
 #define CONFIG_FILE "./tray-monitor.conf"   /* default configuration file */
 
 static void usage()
@@ -118,7 +119,8 @@ PROG_COPYRIGHT
 }
 
 static GtkWidget *new_image_button(const gchar *stock_id,
-                                   const gchar *label_text) {
+                                   const gchar *label_text)
+{
     GtkWidget *button;
     GtkWidget *box;
     GtkWidget *label;
@@ -188,6 +190,7 @@ int main(int argc, char *argv[])
    DIRRES* dird;
    CLIENT* filed;
    STORE* stored;
+   CONFONTRES *con_font;
 
    setlocale(LC_ALL, "");
    bindtextdomain("bacula", LOCALEDIR);
@@ -204,7 +207,7 @@ int main(int argc, char *argv[])
    sigfillset(&sigignore.sa_mask);
    sigaction(SIGPIPE, &sigignore, NULL);
 
-   gtk_init (&argc, &argv);
+   gtk_init(&argc, &argv);
 
    while ((ch = getopt(argc, argv, "bc:d:th?f:s:")) != -1) {
       switch (ch) {
@@ -255,7 +258,7 @@ int main(int argc, char *argv[])
 
    if (nitems != 1) {
       Emsg2(M_ERROR_TERM, 0,
-         _("Error: %d Monitor resource defined in %s. You must define one and only one Monitor resource.\n"), nitems, configfile);
+         _("Error: %d Monitor resources defined in %s. You must define one and only one Monitor resource.\n"), nitems, configfile);
    }
 
    nitems = 0;
@@ -286,7 +289,7 @@ int main(int argc, char *argv[])
    UnlockRes();
 
    if (nitems == 0) {
-      Emsg1(M_ERROR_TERM, 0, _("No Client, Storage nor Director resource defined in %s\n"
+      Emsg1(M_ERROR_TERM, 0, _("No Client, Storage or Director resource defined in %s\n"
 "Without that I don't how to get status from the File, Storage or Director Daemon :-(\n"), configfile);
    }
 
@@ -313,8 +316,9 @@ int main(int argc, char *argv[])
    }
 
    GdkPixbuf* pixbuf = gdk_pixbuf_new_from_xpm_data(generateXPM(warn, warn));
-   // This should be ideally replaced by a completely libpr0n-based icon rendering.
-   mTrayIcon = egg_status_icon_new_from_pixbuf(pixbuf);
+
+   mTrayIcon = gtk_status_icon_new_from_pixbuf(pixbuf);
+   gtk_status_icon_set_tooltip(mTrayIcon, _("Bacula daemon status monitor"));
    g_signal_connect(G_OBJECT(mTrayIcon), "activate", G_CALLBACK(TrayIconActivate), NULL);
    g_signal_connect(G_OBJECT(mTrayIcon), "popup-menu", G_CALLBACK(TrayIconPopupMenu), NULL);
    g_object_unref(G_OBJECT(pixbuf));
@@ -337,7 +341,7 @@ int main(int argc, char *argv[])
 
    timerTag = g_timeout_add( 1000*monitor->RefreshInterval/nitems, fd_read, NULL );
 
-   g_timeout_add( 1000, blink, NULL );
+   g_timeout_add( 1000, blink, NULL);
 
    window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 
@@ -412,7 +416,36 @@ int main(int argc, char *argv[])
 
    gtk_text_buffer_set_text(buffer, "", -1);
 
-   PangoFontDescription *font_desc = pango_font_description_from_string ("Fixed 10");
+  /*
+   * Gtk2/pango have different font names. Gnome2 comes with "Monospace 10"
+   */
+
+   LockRes();
+   foreach_res(con_font, R_CONSOLE_FONT) {
+       if (!con_font->fontface) {
+          Dmsg1(400, "No fontface for %s\n", con_font->hdr.name);
+          continue;
+       }
+       Dmsg1(100, "Now loading: %s\n",con_font->fontface);
+       font_desc = pango_font_description_from_string(con_font->fontface);
+       if (font_desc == NULL) {
+           Dmsg2(400, "Load of requested ConsoleFont \"%s\" (%s) failed!\n",
+                  con_font->hdr.name, con_font->fontface);
+       } else {
+           Dmsg2(400, "ConsoleFont \"%s\" (%s) loaded.\n",
+                  con_font->hdr.name, con_font->fontface);
+           break;
+       }
+   }
+   UnlockRes();
+
+   if (!font_desc) {
+      font_desc = pango_font_description_from_string("Monospace 10");
+   }
+   if (!font_desc) {
+      font_desc = pango_font_description_from_string("monospace");
+   }
+
    gtk_widget_modify_font(textview, font_desc);
    pango_font_description_free(font_desc);
 
@@ -500,7 +533,8 @@ int main(int argc, char *argv[])
    return 0;
 }
 
-static void MonitorAbout(GtkWidget *widget, gpointer data) {
+static void MonitorAbout(GtkWidget *widget, gpointer data)
+{
 #if HAVE_GTK_2_4
    GtkWidget* about = gtk_message_dialog_new_with_markup(GTK_WINDOW(window),GTK_DIALOG_MODAL, GTK_MESSAGE_INFO, GTK_BUTTONS_CLOSE,
       "<span size='x-large' weight='bold'>%s</span>\n\n"
@@ -528,33 +562,46 @@ static void MonitorAbout(GtkWidget *widget, gpointer data) {
    gtk_widget_destroy(about);
 }
 
-static void MonitorRefresh(GtkWidget *widget, gpointer data) {
+static void MonitorRefresh(GtkWidget *widget, gpointer data)
+{
    for (int i = 0; i < nitems; i++) {
       fd_read(NULL);
    }
 }
 
-static gboolean delete_event( GtkWidget *widget,
-                              GdkEvent  *event,
-                              gpointer   data ) {
+static gboolean delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
+{
    gtk_widget_hide(window);
    return TRUE; /* do not destroy the window */
 }
 
-static void TrayIconActivate(GtkWidget *widget, gpointer data) {
-    gtk_widget_show(window);
+/*
+ * Come here when the user right clicks on the icon.
+ *   We display the icon menu.
+ */
+static void TrayIconActivate(GtkWidget *widget, gpointer data)
+{
+   gtk_widget_show(window);
 }
 
-static void TrayIconPopupMenu(unsigned int activateTime, unsigned int button) {
-  gtk_menu_popup(GTK_MENU(mTrayMenu), NULL, NULL, NULL, NULL, 1, 0);
-  gtk_widget_show_all(mTrayMenu);
+/*
+ * Come here when the user left clicks on the icon. 
+ *  We popup the status window.
+ */
+static void TrayIconPopupMenu(unsigned int activateTime, unsigned int button) 
+{
+   gtk_menu_popup(GTK_MENU(mTrayMenu), NULL, NULL, NULL, NULL, button,
+                  gtk_get_current_event_time());
+   gtk_widget_show(mTrayMenu);
 }
 
-static void TrayIconExit(unsigned int activateTime, unsigned int button) {
+static void TrayIconExit(unsigned int activateTime, unsigned int button)
+{
    gtk_main_quit();
 }
 
-static void IntervalChanged(GtkWidget *widget, gpointer data) {
+static void IntervalChanged(GtkWidget *widget, gpointer data)
+{
    g_source_remove(timerTag);
    timerTag = g_timeout_add(
       (guint)(
@@ -562,7 +609,8 @@ static void IntervalChanged(GtkWidget *widget, gpointer data) {
       ), fd_read, NULL );
 }
 
-static void DaemonChanged(GtkWidget *widget, monitoritem* data) {
+static void DaemonChanged(GtkWidget *widget, monitoritem* data) 
+{
    if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget))) {
       fullitem = -1;
       for (int i = 0; i < nitems; i++) {
@@ -871,21 +919,21 @@ int docmd(monitoritem* item, const char* command, GSList** list)
          dird = (DIRRES*)item->resource;
          trayMessage(_("Connecting to Director %s:%d\n"), dird->address, dird->DIRport);
          changeStatusMessage(item, _("Connecting to Director %s:%d"), dird->address, dird->DIRport);
-         item->D_sock = bnet_connect(NULL, 0, 0, _("Director daemon"), dird->address, NULL, dird->DIRport, 0);
+         item->D_sock = bnet_connect(NULL, 0, 0, 0, _("Director daemon"), dird->address, NULL, dird->DIRport, 0);
          jcr.dir_bsock = item->D_sock;
          break;
       case R_CLIENT:
          filed = (CLIENT*)item->resource;
          trayMessage(_("Connecting to Client %s:%d\n"), filed->address, filed->FDport);
          changeStatusMessage(item, _("Connecting to Client %s:%d"), filed->address, filed->FDport);
-         item->D_sock = bnet_connect(NULL, 0, 0, _("File daemon"), filed->address, NULL, filed->FDport, 0);
+         item->D_sock = bnet_connect(NULL, 0, 0, 0, _("File daemon"), filed->address, NULL, filed->FDport, 0);
          jcr.file_bsock = item->D_sock;
          break;
       case R_STORAGE:
          stored = (STORE*)item->resource;
          trayMessage(_("Connecting to Storage %s:%d\n"), stored->address, stored->SDport);
          changeStatusMessage(item, _("Connecting to Storage %s:%d"), stored->address, stored->SDport);
-         item->D_sock = bnet_connect(NULL, 0, 0, _("Storage daemon"), stored->address, NULL, stored->SDport, 0);
+         item->D_sock = bnet_connect(NULL, 0, 0, 0, _("Storage daemon"), stored->address, NULL, stored->SDport, 0);
          jcr.store_bsock = item->D_sock;
          break;
       default:
@@ -1016,7 +1064,7 @@ void trayMessage(const char *fmt,...)
 
    fprintf(stderr, buf);
 
-   egg_tray_icon_send_message(egg_status_icon_get_tray_icon(mTrayIcon), 5000, (const char*)&buf, -1);
+// gtk_tray_icon_send_message(gtk_status_icon_get_tray_icon(mTrayIcon), 5000, (const char*)&buf, -1);
 }
 
 void changeStatusMessage(monitoritem* item, const char *fmt,...) {
@@ -1075,7 +1123,7 @@ void updateStatusIcon(monitoritem* item) {
 
    GdkPixbuf* pixbuf = gdk_pixbuf_new_from_xpm_data(xpm);
    if (item == NULL) {
-      egg_status_icon_set_from_pixbuf(mTrayIcon, pixbuf);
+      gtk_status_icon_set_from_pixbuf(mTrayIcon, pixbuf);
       gtk_window_set_icon(GTK_WINDOW(window), pixbuf);
    }
    else {
@@ -1085,7 +1133,8 @@ void updateStatusIcon(monitoritem* item) {
 }
 
 /* Note: result should not be stored, as it is a reference to xpm_generic_var */
-static const char** generateXPM(stateenum newstate, stateenum oldstate) {
+static const char** generateXPM(stateenum newstate, stateenum oldstate) 
+{
    char* address = &xpm_generic_var[xpm_generic_first_color][xpm_generic_column];
    switch (newstate) {
    case error:
