@@ -9,14 +9,14 @@
 /*
    Bacula® - The Network Backup Solution
 
-   Copyright (C) 2005-2006 Free Software Foundation Europe e.V.
+   Copyright (C) 2005-2007 Free Software Foundation Europe e.V.
 
    The main author of Bacula is Kern Sibbald, with contributions from
    many others, a complete list can be found in the file AUTHORS.
    This program is Free Software; you can redistribute it and/or
    modify it under the terms of version two of the GNU General Public
-   License as published by the Free Software Foundation plus additions
-   that are listed in the file LICENSE.
+   License as published by the Free Software Foundation and included
+   in the file LICENSE.
 
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -46,26 +46,40 @@
 
 VSSClient *g_pVSSClient;
 
+// {b5946137-7b9f-4925-af80-51abd60b20d5}
+
+static const GUID VSS_SWPRV_ProviderID =
+   { 0xb5946137, 0x7b9f, 0x4925, { 0xaf, 0x80, 0x51, 0xab, 0xd6, 0x0b, 0x20, 0xd5 } };
+
+
 void 
 VSSCleanup()
 {
-   if (g_pVSSClient)
+   if (g_pVSSClient) {
       delete (g_pVSSClient);
+   }
 }
 
-void
-VSSInit()
+void VSSInit()
 {
    /* decide which vss class to initialize */
-   switch (g_MinorVersion) {
+   if (g_MajorVersion == 5) {
+      switch (g_MinorVersion) {
       case 1: 
          g_pVSSClient = new VSSClientXP();
          atexit(VSSCleanup);
-         break;
+         return;
       case 2: 
          g_pVSSClient = new VSSClient2003();
          atexit(VSSCleanup);
-         break;
+         return;
+      }
+   /* Vista or Longhorn */
+   } else if (g_MajorVersion == 6 && g_MinorVersion == 0) {
+      /* Probably will not work */
+      g_pVSSClient = new VSSClientVista();
+      atexit(VSSCleanup);
+      return;
    }
 }
 
@@ -90,8 +104,8 @@ VSSClient::VSSClient()
     m_bDuringRestore = false;
     m_bBackupIsInitialized = false;
     m_pVssObject = NULL;
-    m_pAlistWriterState = New (alist(10, not_owned_by_alist));
-    m_pAlistWriterInfoText = New (alist(10, owned_by_alist));
+    m_pAlistWriterState = New(alist(10, not_owned_by_alist));
+    m_pAlistWriterInfoText = New(alist(10, owned_by_alist));
     m_uidCurrentSnapshotSet = GUID_NULL;
     memset(m_wszUniqueVolumeName, 0, sizeof(m_wszUniqueVolumeName));
     memset(m_szShadowCopyName, 0, sizeof(m_szShadowCopyName));
@@ -108,8 +122,8 @@ VSSClient::~VSSClient()
    }
 
    DestroyWriterInfo();
-   delete (alist*) m_pAlistWriterState;
-   delete (alist*) m_pAlistWriterInfoText;
+   delete (alist*)m_pAlistWriterState;
+   delete (alist*)m_pAlistWriterInfoText;
 
    // Call CoUninitialize if the CoInitialize was performed successfully
    if (m_bCoInitializeCalled)
