@@ -4,7 +4,7 @@
  *
  *    Nicolas Boichat, May 2004
  *
- *    Version $Id: wxbconfigfileeditor.cpp 3685 2006-11-22 14:26:40Z kerns $
+ *    Version $Id: wxbconfigfileeditor.cpp 4992 2007-06-07 14:46:43Z kerns $
  */
 /*
    Bacula® - The Network Backup Solution
@@ -15,8 +15,8 @@
    many others, a complete list can be found in the file AUTHORS.
    This program is Free Software; you can redistribute it and/or
    modify it under the terms of version two of the GNU General Public
-   License as published by the Free Software Foundation plus additions
-   that are listed in the file LICENSE.
+   License as published by the Free Software Foundation and included
+   in the file LICENSE.
 
    This program is distributed in the hope that it will be useful, but
    WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -72,7 +72,7 @@ wxbConfigFileEditor::wxbConfigFileEditor(wxWindow* parent, wxString filename):
    
    if (!filen.FileExists()) {
       strbuf << wxT("#\n");
-      strbuf << _("# Bacula wx-console Configuration File\n");
+      strbuf << _("# Bacula bwx-console Configuration File\n");
       strbuf << wxT("#\n");
       strbuf << wxT("\n");
       strbuf << wxT("Director {\n");
